# Generated by Django 3.2.16 on 2022-11-26 18:42

import django.contrib.auth.models
from django.db import migrations
from django.conf import settings


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("auth", "0012_alter_user_first_name_max_length"),
    ]

    operations = [
        migrations.CreateModel(
            name="DescopeUser",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=(settings.AUTH_USER_MODEL,),
            managers=[
                ("objects", django.contrib.auth.models.UserManager()),
            ],
        ),
    ]
